@@ -383,9 +383,8 @@ int CControlSocket::CheckOverwriteFile()
 	if (found && !matchedCase)
 		found = false;
 
-	if (!pData->download)
-	{
-		if (!found && pData->remoteFileSize == -1 && !pData->fileTime.IsValid())
+	if (!pData->download) {
+		if (!found && pData->remoteFileSize < 0 && !pData->fileTime.IsValid())
 			return FZ_REPLY_OK;
 	}
 
@@ -399,9 +398,9 @@ int CControlSocket::CheckOverwriteFile()
 	pNotification->remoteSize = pData->remoteFileSize;
 	pNotification->ascii = !pData->transferSettings.binary;
 
-	if (pData->download && pNotification->localSize != -1)
+	if (pData->download && pNotification->localSize >= 0)
 		pNotification->canResume = true;
-	else if (!pData->download && pNotification->remoteSize != -1)
+	else if (!pData->download && pNotification->remoteSize >= 0)
 		pNotification->canResume = true;
 	else
 		pNotification->canResume = false;
@@ -428,9 +427,7 @@ int CControlSocket::CheckOverwriteFile()
 CFileTransferOpData::CFileTransferOpData(bool is_download, const wxString& local_file, const wxString& remote_file, const CServerPath& remote_path) :
 	COpData(Command::transfer),
 	localFile(local_file), remoteFile(remote_file), remotePath(remote_path),
-	download(is_download),
-	localFileSize(-1), remoteFileSize(-1),
-	tryAbsolutePath(false), resume(false), transferInitiated(false)
+	download(is_download)
 {
 }
 
@@ -1159,7 +1156,7 @@ bool CControlSocket::SetFileExistsAction(CFileExistsNotification *pFileExistsNot
 	case CFileExistsNotification::overwriteSize:
 		/* First compare flags both size known but different, one size known and the other not (obviously they are different).
 		Second compare flags the remaining case in which we need to send command : both size unknown */
-		if ((pFileExistsNotification->localSize != pFileExistsNotification->remoteSize) || (pFileExistsNotification->localSize == -1))
+		if ((pFileExistsNotification->localSize != pFileExistsNotification->remoteSize) || (pFileExistsNotification->localSize < 0))
 			SendNextCommand();
 		else {
 			if (pData->download) {
@@ -1177,7 +1174,7 @@ bool CControlSocket::SetFileExistsAction(CFileExistsNotification *pFileExistsNot
 			SendNextCommand();
 		/* First compare flags both size known but different, one size known and the other not (obviously they are different).
 		Second compare flags the remaining case in which we need to send command : both size unknown */
-		else if ((pFileExistsNotification->localSize != pFileExistsNotification->remoteSize) || (pFileExistsNotification->localSize == -1))
+		else if ((pFileExistsNotification->localSize != pFileExistsNotification->remoteSize) || (pFileExistsNotification->localSize < 0))
 			SendNextCommand();
 		else if (pFileExistsNotification->download && pFileExistsNotification->localTime.IsEarlierThan(pFileExistsNotification->remoteTime))
 			SendNextCommand();
@@ -1198,9 +1195,9 @@ bool CControlSocket::SetFileExistsAction(CFileExistsNotification *pFileExistsNot
 		}
 		break;
 	case CFileExistsNotification::resume:
-		if (pData->download && pData->localFileSize != -1)
+		if (pData->download && pData->localFileSize >= 0)
 			pData->resume = true;
-		else if (!pData->download && pData->remoteFileSize != -1)
+		else if (!pData->download && pData->remoteFileSize >= 0)
 			pData->resume = true;
 		SendNextCommand();
 		break;
@@ -1275,17 +1272,15 @@ void CControlSocket::CreateLocalDir(const wxString &local_file)
 
 	// Only go back as far as needed. On comparison, wxWidgets'
 	// wxFileName::Mkdir always starts at the root.
-	std::list<wxString> segments;
-	while (!local_path.Exists() && local_path.HasParent())
-	{
+	std::vector<wxString> segments;
+	while (!local_path.Exists() && local_path.HasParent()) {
 		wxString segment;
 		local_path.MakeParent(&segment);
-		segments.push_front(segment);
+		segments.push_back(segment);
 	}
 
 	CLocalPath last_successful;
-	for (std::list<wxString>::const_iterator iter = segments.begin(); iter != segments.end(); ++iter)
-	{
+	for (auto iter = segments.rbegin(); iter != segments.rend(); ++iter) {
 		local_path.AddSegment(*iter);
 
 #ifdef __WXMSW__
@@ -1328,7 +1323,7 @@ int CControlSocket::RawCommand(const wxString&)
 	return FZ_REPLY_NOTSUPPORTED;
 }
 
-int CControlSocket::Delete(const CServerPath&, const std::list<wxString>&)
+int CControlSocket::Delete(const CServerPath&, std::deque<wxString>&&)
 {
 	return FZ_REPLY_NOTSUPPORTED;
 }
