@@ -11,6 +11,9 @@ public:
 	COpData(Command op_Id);
 	virtual ~COpData();
 
+	COpData(COpData const&) = delete;
+	COpData& operator=(COpData const&) = delete;
+
 	int opState;
 	Command const opId;
 
@@ -24,8 +27,8 @@ class CConnectOpData : public COpData
 {
 public:
 	CConnectOpData()
-		: COpData(Command::connect),
-		port(0)
+		: COpData(Command::connect)
+		, port(0)
 	{
 	}
 
@@ -44,17 +47,17 @@ public:
 	const bool download;
 
 	CDateTime fileTime;
-	wxFileOffset localFileSize;
-	wxFileOffset remoteFileSize;
+	wxFileOffset localFileSize{-1};
+	wxFileOffset remoteFileSize{-1};
 
-	bool tryAbsolutePath;
-	bool resume;
+	bool tryAbsolutePath{};
+	bool resume{};
 
 	CFileTransferCommand::t_transferSettings transferSettings;
 
 	// Set to true when sending the command which
 	// starts the actual transfer
-	bool transferInitiated;
+	bool transferInitiated{};
 };
 
 class CMkdirOpData : public COpData
@@ -72,7 +75,7 @@ public:
 	CServerPath path;
 	CServerPath currentPath;
 	CServerPath commonParent;
-	std::list<wxString> segments;
+	std::vector<wxString> segments;
 };
 
 class CChangeDirOpData : public COpData
@@ -118,6 +121,9 @@ public:
 	CControlSocket(CFileZillaEnginePrivate & engine);
 	virtual ~CControlSocket();
 
+	CControlSocket(CControlSocket const&) = delete;
+	CControlSocket& operator=(CControlSocket const&) = delete;
+
 	virtual int Connect(const CServer &server) = 0;
 	virtual int Disconnect();
 	virtual void Cancel();
@@ -126,7 +132,7 @@ public:
 							 const wxString &remoteFile, bool download,
 							 const CFileTransferCommand::t_transferSettings& transferSettings);
 	virtual int RawCommand(const wxString& command = wxString());
-	virtual int Delete(const CServerPath& path, const std::list<wxString>& files);
+	virtual int Delete(const CServerPath& path, std::deque<wxString>&& files);
 	virtual int RemoveDir(const CServerPath& path = CServerPath(), const wxString& subDir = wxString());
 	virtual int Mkdir(const CServerPath& path);
 	virtual int Rename(const CRenameCommand& command);
