@@ -47,12 +47,15 @@ namespace listingEncoding
 }
 
 
-class CDirectoryListingParser
+class CDirectoryListingParser final
 {
 public:
 	CDirectoryListingParser(CControlSocket* pControlSocket, const CServer& server, listingEncoding::type encoding = listingEncoding::unknown, bool sftp_mode = false);
 	~CDirectoryListingParser();
 
+	CDirectoryListingParser(CDirectoryListingParser const&) = delete;
+	CDirectoryListingParser& operator=(CDirectoryListingParser const&) = delete;
+
 	CDirectoryListing Parse(const CServerPath &path);
 
 	bool AddData(char *pData, int len);
@@ -124,7 +127,7 @@ protected:
 
 	int m_currentOffset;
 
-	std::list<t_list> m_DataList;
+	std::deque<t_list> m_DataList;
 	std::deque<CRefcountObject<CDirentry>> m_entryList;
 	wxLongLong m_totalData;
 
@@ -133,7 +136,7 @@ protected:
 	CServer m_server;
 
 	bool m_fileListOnly;
-	std::list<wxString> m_fileList;
+	std::vector<wxString> m_fileList;
 
 	bool m_maybeMultilineVms;
 
