@@ -14,7 +14,7 @@ class CFtpTransferOpData;
 class CRawTransferOpData;
 class CTlsSocket;
 
-class CFtpControlSocket : public CRealControlSocket
+class CFtpControlSocket final : public CRealControlSocket
 {
 	friend class CTransferSocket;
 public:
@@ -52,7 +52,7 @@ protected:
 	int RawCommandSend();
 	int RawCommandParseResponse();
 
-	virtual int Delete(const CServerPath& path, const std::list<wxString>& files);
+	virtual int Delete(const CServerPath& path, std::deque<wxString>&& files);
 	int DeleteSubcommandResult(int prevResult);
 	int DeleteSend();
 	int DeleteParseResponse();
@@ -121,7 +121,7 @@ protected:
 
 	wxString m_Response;
 	wxString m_MultilineResponseCode;
-	std::list<wxString> m_MultilineResponseLines;
+	std::vector<wxString> m_MultilineResponseLines;
 
 	CTransferSocket *m_pTransferSocket;
 
@@ -161,14 +161,14 @@ class CIOThread;
 class CFtpTransferOpData
 {
 public:
-	CFtpTransferOpData();
+	CFtpTransferOpData() = default;
 	virtual ~CFtpTransferOpData() {}
 
-	TransferEndReason transferEndReason;
-	bool tranferCommandSent;
+	TransferEndReason transferEndReason{TransferEndReason::successful};
+	bool tranferCommandSent{};
 
-	wxLongLong resumeOffset;
-	bool binary;
+	wxLongLong resumeOffset{};
+	bool binary{true};
 };
 
 class CFtpFileTransferOpData final : public CFileTransferOpData, public CFtpTransferOpData
@@ -177,8 +177,8 @@ public:
 	CFtpFileTransferOpData(bool is_download, const wxString& local_file, const wxString& remote_file, const CServerPath& remote_path);
 	virtual ~CFtpFileTransferOpData();
 
-	CIOThread *pIOThread;
-	bool fileDidExist;
+	CIOThread *pIOThread{};
+	bool fileDidExist{true};
 };
 
 class CRawTransferOpData final : public COpData
