@@ -2,7 +2,7 @@
 
 struct t_protocolInfo
 {
-	const enum ServerProtocol protocol;
+	const ServerProtocol protocol;
 	const wxString prefix;
 	bool alwaysShowPrefix;
 	unsigned int defaultPort;
@@ -12,18 +12,18 @@ struct t_protocolInfo
 };
 
 static const t_protocolInfo protocolInfos[] = {
-	{ FTP,          _T("ftp"),    false, 21,  true,  wxTRANSLATE("FTP - File Transfer Protocol with optional encryption"),                 true  },
+	{ FTP,          _T("ftp"),    false, 21,  true,  TRANSLATE_T("FTP - File Transfer Protocol with optional encryption"),                 true  },
 	{ SFTP,         _T("sftp"),   true,  22,  false, _T("SFTP - SSH File Transfer Protocol"),                              false },
-	{ HTTP,         _T("http"),   true,  80,  false, _T("HTTP - Hypertext Transfer Protocol"),                             true  },
-	{ HTTPS,        _T("https"),  true, 443,  true,  wxTRANSLATE("HTTPS - HTTP over TLS"),                                 true  },
-	{ FTPS,         _T("ftps"),   true, 990,  true,  wxTRANSLATE("FTPS - FTP over implicit TLS/SSL"),                      true  },
-	{ FTPES,        _T("ftpes"),  true,  21,  true,  wxTRANSLATE("FTPES - FTP over explicit TLS/SSL"),                     true  },
-	{ INSECURE_FTP, _T("ftp"),    false, 21,  true,  wxTRANSLATE("FTP - Insecure File Transfer Protocol"), true  },
-	{ UNKNOWN,      _T(""),       false, 21,  false, _T("") }
+	{ HTTP,         _T("http"),   true,  80,  false, _T("HTTP - Hypertext Transfer Protocol"),                             false  },
+	{ HTTPS,        _T("https"),  true, 443,  true,  TRANSLATE_T("HTTPS - HTTP over TLS"),                                 false  },
+	{ FTPS,         _T("ftps"),   true, 990,  true,  TRANSLATE_T("FTPS - FTP over implicit TLS"),                      true  },
+	{ FTPES,        _T("ftpes"),  true,  21,  true,  TRANSLATE_T("FTPES - FTP over explicit TLS"),                     true  },
+	{ INSECURE_FTP, _T("ftp"),    false, 21,  true,  TRANSLATE_T("FTP - Insecure File Transfer Protocol"), true  },
+	{ UNKNOWN,      _T(""),       false, 21,  false, _T(""), false }
 };
 
 static const wxString typeNames[SERVERTYPE_MAX] = {
-	wxTRANSLATE("Default (Autodetect)"),
+	TRANSLATE_T("Default (Autodetect)"),
 	_T("Unix"),
 	_T("VMS"),
 	_T("DOS"),
@@ -31,7 +31,7 @@ static const wxString typeNames[SERVERTYPE_MAX] = {
 	_T("VxWorks"),
 	_T("z/VM"),
 	_T("HP NonStop"),
-	wxTRANSLATE("DOS-like with virtual paths"),
+	TRANSLATE_T("DOS-like with virtual paths"),
 	_T("Cygwin")
 };
 
@@ -51,11 +51,13 @@ CServer::CServer()
 	Initialize();
 }
 
-bool CServer::ParseUrl(wxString host, const wxString& port, wxString user, wxString pass, wxString &error, CServerPath &path)
+bool CServer::ParseUrl(wxString host, wxString port, wxString user, wxString pass, wxString &error, CServerPath &path)
 {
 	unsigned long nPort = 0;
 	if (!port.empty())
 	{
+		port.Trim(false);
+		port.Trim(true);
 		if (port.size() > 5 || !port.ToULong(&nPort) || !nPort || nPort > 65535)
 		{
 			error = _("Invalid port given. The port has to be a value from 1 to 65535.");
@@ -71,15 +73,13 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 {
 	m_type = DEFAULT;
 
-	if (host == _T(""))
-	{
+	if (host.empty()) {
 		error = _("No host given, please enter a host.");
 		return false;
 	}
 
 	int pos = host.Find(_T("://"));
-	if (pos != -1)
-	{
+	if (pos != -1) {
 		wxString protocol = host.Left(pos).Lower();
 		host = host.Mid(pos + 3);
 		if (protocol.Left(3) == _T("fz_"))
@@ -88,14 +88,13 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 		if (m_protocol == UNKNOWN)
 		{
 			// TODO: http:// once WebDAV is officially supported
-			error = _("Invalid protocol specified. Valid protocols are:\nftp:// for normal FTP,\nsftp:// for SSH file transfer protocol,\nftps:// for FTP over SSL (implicit) and\nftpes:// for FTP over SSL (explicit).");
+			error = _("Invalid protocol specified. Valid protocols are:\nftp:// for normal FTP with optional encryption,\nsftp:// for SSH file transfer protocol,\nftps:// for FTP over TLS (implicit) and\nftpes:// for FTP over TLS (explicit).");
 			return false;
 		}
 	}
 
 	pos = host.Find('@');
-	if (pos != -1)
-	{
+	if (pos != -1) {
 		// Check if it's something like
 		//   user@name:password@host:port/path
 		// => If there are multiple at signs, username/port ends at last at before
@@ -106,8 +105,7 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 			slash += pos + 1;
 
 		int next_at = host.Mid(pos + 1).Find('@');
-		while (next_at != -1)
-		{
+		while (next_at != -1) {
 			next_at += pos + 1;
 			if (slash != -1 && next_at > slash)
 				break;
@@ -121,8 +119,7 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 
 		// Extract password (if any) from username
 		pos = user.Find(':');
-		if (pos != -1)
-		{
+		if (pos != -1) {
 			pass = user.Mid(pos + 1);
 			user = user.Left(pos);
 		}
@@ -131,45 +128,37 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 		user.Trim(true);
 		user.Trim(false);
 
-		if (user == _T(""))
-		{
+		if (user.empty()) {
 			error = _("Invalid username given.");
 			return false;
 		}
 	}
-	else
-	{
+	else {
 		// Remove leading and trailing whitespace
 		user.Trim(true);
 		user.Trim(false);
 
-		if (user == _T("") && m_logonType != ASK && m_logonType != INTERACTIVE)
-		{
+		if (user.empty() && m_logonType != ASK && m_logonType != INTERACTIVE) {
 			user = _T("anonymous");
 			pass = _T("anonymous@example.com");
 		}
 	}
 
 	pos = host.Find('/');
-	if (pos != -1)
-	{
+	if (pos != -1) {
 		path = CServerPath(host.Mid(pos));
 		host = host.Left(pos);
 	}
 
-	if (host[0] == '[')
-	{
+	if (!host.empty() && host[0] == '[') {
 		// Probably IPv6 address
 		pos = host.Find(']');
-		if (pos == -1)
-		{
+		if (pos == -1) {
 			error = _("Host starts with '[' but no closing bracket found.");
 			return false;
 		}
-		if (host[pos + 1])
-		{
-			if (host[pos + 1] != ':')
-			{
+		if (pos + 1 < static_cast<int>(host.Len()) ) {
+			if (host[pos + 1] != ':') {
 				error = _("Invalid host, after closing bracket only colon and port may follow.");
 				return false;
 			}
@@ -180,29 +169,24 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 	}
 	else
 		pos = host.Find(':');
-	if (pos != -1)
-	{
-		if (!pos)
-		{
+	if (pos != -1) {
+		if (!pos) {
 			error = _("No host given, please enter a host.");
 			return false;
 		}
 
 		long tmp;
-		if (!host.Mid(pos + 1).ToLong(&tmp) || tmp < 1 || tmp > 65535)
-		{
+		if (!host.Mid(pos + 1).ToLong(&tmp) || tmp < 1 || tmp > 65535) {
 			error = _("Invalid port given. The port has to be a value from 1 to 65535.");
 			return false;
 		}
 		port = tmp;
 		host = host.Left(pos);
 	}
-	else
-	{
+	else {
 		if (!port)
 			port = GetDefaultPort(m_protocol);
-		else if (port > 65535)
-		{
+		else if (port > 65535) {
 			error = _("Invalid port given. The port has to be a value from 1 to 65535.");
 			return false;
 		}
@@ -211,16 +195,14 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 	host.Trim(true);
 	host.Trim(false);
 
-	if (host == _T(""))
-	{
+	if (host.empty()) {
 		error = _("No host given, please enter a host.");
 		return false;
 	}
 
 	m_host = host;
 
-	if (m_host[0] == '[')
-	{
+	if (m_host[0] == '[') {
 		m_host.RemoveLast();
 		m_host = m_host.Mid(1);
 	}
@@ -228,11 +210,15 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 	m_port = port;
 	m_user = user;
 	m_pass = pass;
-	m_account = _T("");
-	if (m_logonType != ASK && m_logonType != INTERACTIVE)
-	{
-		if (m_user == _T("") || m_user == _T("anonymous"))
+	m_account.clear();
+	if (m_logonType != ASK && m_logonType != INTERACTIVE) {
+		if (m_user.empty())
 			m_logonType = ANONYMOUS;
+		else if (m_user == _T("anonymous"))
+			if (m_pass.empty() || m_pass == _T("anonymous@example.com"))
+				m_logonType = ANONYMOUS;
+			else
+				m_logonType = NORMAL;
 		else
 			m_logonType = NORMAL;
 	}
@@ -282,7 +268,7 @@ wxString CServer::GetPass() const
 wxString CServer::GetAccount() const
 {
 	if (m_logonType != ACCOUNT)
-		return _T("");
+		return wxString();
 
 	return m_account;
 }
@@ -466,12 +452,17 @@ bool CServer::EqualsNoPass(const CServer &op) const
 		return false;
 	else if (m_port != op.m_port)
 		return false;
-	else if (m_logonType != op.m_logonType)
+	else if ((m_logonType == ANONYMOUS) != (op.m_logonType == ANONYMOUS))
+		return false;
+	else if ((m_logonType == ACCOUNT) != (op.m_logonType == ACCOUNT))
 		return false;
 	else if (m_logonType != ANONYMOUS)
 	{
 		if (m_user != op.m_user)
 			return false;
+		if (m_logonType == ACCOUNT)
+			if (m_account != op.m_account)
+				return false;
 	}
 	if (m_timezoneOffset != op.m_timezoneOffset)
 		return false;
@@ -479,8 +470,7 @@ bool CServer::EqualsNoPass(const CServer &op) const
 		return false;
 	else if (m_encodingType != op.m_encodingType)
 		return false;
-	else if (m_encodingType == ENCODING_CUSTOM)
-	{
+	else if (m_encodingType == ENCODING_CUSTOM) {
 		if (m_customEncoding != op.m_customEncoding)
 			return false;
 	}
@@ -494,7 +484,7 @@ bool CServer::EqualsNoPass(const CServer &op) const
 	return true;
 }
 
-CServer::CServer(enum ServerProtocol protocol, enum ServerType type, wxString host, unsigned int port, wxString user, wxString pass /*=_T("")*/, wxString account /*=_T("")*/)
+CServer::CServer(ServerProtocol protocol, ServerType type, wxString host, unsigned int port, wxString user, wxString pass, wxString account)
 {
 	Initialize();
 	m_protocol = protocol;
@@ -507,7 +497,7 @@ CServer::CServer(enum ServerProtocol protocol, enum ServerType type, wxString ho
 	m_account = account;
 }
 
-CServer::CServer(enum ServerProtocol protocol, enum ServerType type, wxString host, unsigned int port)
+CServer::CServer(ServerProtocol protocol, ServerType type, wxString host, unsigned int port)
 {
 	Initialize();
 	m_protocol = protocol;
@@ -516,23 +506,23 @@ CServer::CServer(enum ServerProtocol protocol, enum ServerType type, wxString ho
 	m_port = port;
 }
 
-void CServer::SetType(enum ServerType type)
+void CServer::SetType(ServerType type)
 {
 	m_type = type;
 }
 
-enum LogonType CServer::GetLogonType() const
+LogonType CServer::GetLogonType() const
 {
 	return m_logonType;
 }
 
-void CServer::SetLogonType(enum LogonType logonType)
+void CServer::SetLogonType(LogonType logonType)
 {
 	wxASSERT(logonType != LOGONTYPE_MAX);
 	m_logonType = logonType;
 }
 
-void CServer::SetProtocol(enum ServerProtocol serverProtocol)
+void CServer::SetProtocol(ServerProtocol serverProtocol)
 {
 	wxASSERT(serverProtocol != UNKNOWN);
 
@@ -544,7 +534,7 @@ void CServer::SetProtocol(enum ServerProtocol serverProtocol)
 
 bool CServer::SetHost(wxString host, unsigned int port)
 {
-	if (host == _T(""))
+	if (host.empty())
 		return false;
 
 	if (port < 1 || port > 65535)
@@ -559,22 +549,21 @@ bool CServer::SetHost(wxString host, unsigned int port)
 	return true;
 }
 
-bool CServer::SetUser(const wxString& user, const wxString& pass /*=_T("")*/)
+bool CServer::SetUser(const wxString& user, const wxString& pass)
 {
 	if (m_logonType == ANONYMOUS)
 		return true;
 
-	if (user == _T(""))
-	{
+	if (user.empty()) {
 		if (m_logonType != ASK && m_logonType != INTERACTIVE)
 			return false;
-		m_pass = _T("");
+		m_pass.clear();
 	}
 	else
 		m_pass = pass;
-	
+
 	m_user = user;
-	
+
 	return true;
 }
 
@@ -603,12 +592,12 @@ int CServer::GetTimezoneOffset() const
 	return m_timezoneOffset;
 }
 
-enum PasvMode CServer::GetPasvMode() const
+PasvMode CServer::GetPasvMode() const
 {
 	return m_pasvMode;
 }
 
-void CServer::SetPasvMode(enum PasvMode pasvMode)
+void CServer::SetPasvMode(PasvMode pasvMode)
 {
 	m_pasvMode = pasvMode;
 }
@@ -662,23 +651,23 @@ void CServer::Initialize()
 {
 	m_protocol = UNKNOWN;
 	m_type = DEFAULT;
-	m_host = _T("");
+	m_host.clear();
 	m_port = 21;
 	m_logonType = ANONYMOUS;
-	m_user = _T("");
-	m_pass = _T("");
-	m_account = _T("");
+	m_user.clear();
+	m_pass.clear();
+	m_account.clear();
 	m_timezoneOffset = 0;
 	m_pasvMode = MODE_DEFAULT;
 	m_maximumMultipleConnections = 0;
 	m_encodingType = ENCODING_AUTO;
-	m_customEncoding = _T("");
+	m_customEncoding.clear();
 	m_bypassProxy = false;
 }
 
-bool CServer::SetEncodingType(enum CharsetEncoding type, const wxString& encoding /*=_T("")*/)
+bool CServer::SetEncodingType(CharsetEncoding type, const wxString& encoding)
 {
-	if (type == ENCODING_CUSTOM && encoding == _T(""))
+	if (type == ENCODING_CUSTOM && encoding.empty())
 		return false;
 
 	m_encodingType = type;
@@ -689,7 +678,7 @@ bool CServer::SetEncodingType(enum CharsetEncoding type, const wxString& encodin
 
 bool CServer::SetCustomEncoding(const wxString& encoding)
 {
-	if (encoding == _T(""))
+	if (encoding.empty())
 		return false;
 
 	m_encodingType = ENCODING_CUSTOM;
@@ -698,7 +687,7 @@ bool CServer::SetCustomEncoding(const wxString& encoding)
 	return true;
 }
 
-enum CharsetEncoding CServer::GetEncodingType() const
+CharsetEncoding CServer::GetEncodingType() const
 {
 	return m_encodingType;
 }
@@ -708,14 +697,14 @@ wxString CServer::GetCustomEncoding() const
 	return m_customEncoding;
 }
 
-unsigned int CServer::GetDefaultPort(enum ServerProtocol protocol)
+unsigned int CServer::GetDefaultPort(ServerProtocol protocol)
 {
 	const t_protocolInfo& info = GetProtocolInfo(protocol);
 
 	return info.defaultPort;
 }
 
-enum ServerProtocol CServer::GetProtocolFromPort(unsigned int port, bool defaultOnly /*=false*/)
+ServerProtocol CServer::GetProtocolFromPort(unsigned int port, bool defaultOnly /*=false*/)
 {
 	for (unsigned int i = 0; protocolInfos[i].protocol != UNKNOWN; ++i)
 	{
@@ -730,7 +719,7 @@ enum ServerProtocol CServer::GetProtocolFromPort(unsigned int port, bool default
 	return FTP;
 }
 
-wxString CServer::GetProtocolName(enum ServerProtocol protocol)
+wxString CServer::GetProtocolName(ServerProtocol protocol)
 {
 	const t_protocolInfo *protocolInfo = protocolInfos;
 	while (protocolInfo->protocol != UNKNOWN)
@@ -747,21 +736,18 @@ wxString CServer::GetProtocolName(enum ServerProtocol protocol)
 			return protocolInfo->name;
 	}
 
-	return _T("");
+	return wxString();
 }
 
-enum ServerProtocol CServer::GetProtocolFromName(const wxString& name)
+ServerProtocol CServer::GetProtocolFromName(const wxString& name)
 {
 	const t_protocolInfo *protocolInfo = protocolInfos;
-	while (protocolInfo->protocol != UNKNOWN)
-	{
-		if (protocolInfo->translateable)
-		{
+	while (protocolInfo->protocol != UNKNOWN) {
+		if (protocolInfo->translateable) {
 			if (wxGetTranslation(protocolInfo->name) == name)
 				return protocolInfo->protocol;
 		}
-		else
-		{
+		else {
 			if (protocolInfo->name == name)
 				return protocolInfo->protocol;
 		}
@@ -773,9 +759,8 @@ enum ServerProtocol CServer::GetProtocolFromName(const wxString& name)
 
 bool CServer::SetPostLoginCommands(const std::vector<wxString>& postLoginCommands)
 {
-	if (m_protocol != FTP && m_protocol != FTPS && m_protocol != FTPES)
-	{
-		// Currently, only regular FTP supports it
+	if (!SupportsPostLoginCommands(m_protocol)) {
+		m_postLoginCommands.clear();
 		return false;
 	}
 
@@ -783,10 +768,14 @@ bool CServer::SetPostLoginCommands(const std::vector<wxString>& postLoginCommand
 	return true;
 }
 
-enum ServerProtocol CServer::GetProtocolFromPrefix(const wxString& prefix)
+bool CServer::SupportsPostLoginCommands(ServerProtocol const protocol)
 {
-	for (unsigned int i = 0; protocolInfos[i].protocol != UNKNOWN; ++i)
-	{
+	return protocol == FTP || protocol == FTPS || protocol == FTPES || protocol == INSECURE_FTP;
+}
+
+ServerProtocol CServer::GetProtocolFromPrefix(const wxString& prefix)
+{
+	for (unsigned int i = 0; protocolInfos[i].protocol != UNKNOWN; ++i) {
 		if (!protocolInfos[i].prefix.CmpNoCase(prefix))
 			return protocolInfos[i].protocol;
 	}
@@ -794,7 +783,7 @@ enum ServerProtocol CServer::GetProtocolFromPrefix(const wxString& prefix)
 	return UNKNOWN;
 }
 
-wxString CServer::GetPrefixFromProtocol(const enum ServerProtocol protocol)
+wxString CServer::GetPrefixFromProtocol(const ServerProtocol protocol)
 {
 	const t_protocolInfo& info = GetProtocolInfo(protocol);
 
@@ -811,25 +800,24 @@ bool CServer::GetBypassProxy() const
   return m_bypassProxy;
 }
 
-bool CServer::ProtocolHasDataTypeConcept(const enum ServerProtocol protocol)
+bool CServer::ProtocolHasDataTypeConcept(const ServerProtocol protocol)
 {
-	if (protocol == FTP || protocol == FTPS || protocol == FTPES)
+	if (protocol == FTP || protocol == FTPS || protocol == FTPES || protocol == INSECURE_FTP)
 		return true;
 
 	return false;
 }
 
-wxString CServer::GetNameFromServerType(enum ServerType type)
+wxString CServer::GetNameFromServerType(ServerType type)
 {
 	wxASSERT(type != SERVERTYPE_MAX);
 	return wxGetTranslation(typeNames[type]);
 }
 
-enum ServerType CServer::GetServerTypeFromName(const wxString& name)
+ServerType CServer::GetServerTypeFromName(const wxString& name)
 {
-	for (int i = 0; i < SERVERTYPE_MAX; ++i)
-	{
-		enum ServerType type = (enum ServerType)i;
+	for (int i = 0; i < SERVERTYPE_MAX; ++i) {
+		ServerType type = static_cast<ServerType>(i);
 		if (name == CServer::GetNameFromServerType(type))
 			return type;
 	}
@@ -837,7 +825,7 @@ enum ServerType CServer::GetServerTypeFromName(const wxString& name)
 	return DEFAULT;
 }
 
-enum LogonType CServer::GetLogonTypeFromName(const wxString& name)
+LogonType CServer::GetLogonTypeFromName(const wxString& name)
 {
 	if (name == _("Normal"))
 		return NORMAL;
@@ -851,7 +839,7 @@ enum LogonType CServer::GetLogonTypeFromName(const wxString& name)
 		return ANONYMOUS;
 }
 
-wxString CServer::GetNameFromLogonType(enum LogonType type)
+wxString CServer::GetNameFromLogonType(LogonType type)
 {
 	wxASSERT(type != LOGONTYPE_MAX);
 
