@@ -43,7 +43,7 @@ enum sftpRequestTypes
 class CProcess;
 class CSftpInputThread;
 
-class CSftpControlSocket : public CControlSocket, public CRateLimiterObject
+class CSftpControlSocket final : public CControlSocket, public CRateLimiterObject
 {
 public:
 	CSftpControlSocket(CFileZillaEnginePrivate & engine);
@@ -52,7 +52,7 @@ public:
 	virtual int Connect(const CServer &server);
 
 	virtual int List(CServerPath path = CServerPath(), wxString subDir = _T(""), int flags = 0);
-	virtual int Delete(const CServerPath& path, const std::list<wxString>& files);
+	virtual int Delete(const CServerPath& path, std::deque<wxString>&& files);
 	virtual int RemoveDir(const CServerPath& path = CServerPath(), const wxString& subDir = _T(""));
 	virtual int Mkdir(const CServerPath& path);
 	virtual int Rename(const CRenameCommand& command);
