@@ -88,24 +88,25 @@ void ChangeSocketEventHandler(CEventHandler * oldHandler, CEventHandler * newHan
 	if (!newHandler) {
 		RemoveSocketEvents(oldHandler, source);
 	}
-
-	auto socketEventFilter = [&](CEventLoop::Events::value_type & ev) -> bool {
-		if (ev.first == oldHandler) {
-			if (ev.second->derived_type() == CSocketEvent::type()) {
-				if (std::get<0>(static_cast<CSocketEvent const&>(*ev.second).v_) == source) {
-					ev.first = newHandler;
+	else {
+		auto socketEventFilter = [&](CEventLoop::Events::value_type & ev) -> bool {
+			if (ev.first == oldHandler) {
+				if (ev.second->derived_type() == CSocketEvent::type()) {
+					if (std::get<0>(static_cast<CSocketEvent const&>(*ev.second).v_) == source) {
+						ev.first = newHandler;
+					}
+				}
+				else if (ev.second->derived_type() == CHostAddressEvent::type()) {
+					if (std::get<0>(static_cast<CHostAddressEvent const&>(*ev.second).v_) == source) {
+						ev.first = newHandler;
+					}
 				}
 			}
-			else if (ev.second->derived_type() == CHostAddressEvent::type()) {
-				if (std::get<0>(static_cast<CHostAddressEvent const&>(*ev.second).v_) == source) {
-					ev.first = newHandler;
-				}
-			}
-		}
-		return false;
-	};
+			return false;
+		};
 
-	oldHandler->event_loop_.FilterEvents(socketEventFilter);
+		oldHandler->event_loop_.FilterEvents(socketEventFilter);
+	}
 }
 
 namespace {
@@ -992,7 +993,7 @@ void CSocket::SetEventHandler(CEventHandler* pEvtHandler)
 			}
 
 			pEvtHandler->SendEvent<CSocketEvent>(this, SocketEventType::read, 0);
-			if (m_pSocketThread->m_waiting & WAIT_WRITE) {
+			if (m_pSocketThread->m_waiting & WAIT_READ) {
 				m_pSocketThread->m_waiting &= ~WAIT_READ;
 				m_pSocketThread->WakeupThread(l);
 			}
@@ -1002,6 +1003,9 @@ void CSocket::SetEventHandler(CEventHandler* pEvtHandler)
 #endif
 		}
 		else if (pEvtHandler && m_state == closing) {
+			if (!(m_pSocketThread->m_triggered & WAIT_READ)) {
+				m_pSocketThread->m_waiting |= WAIT_READ;
+			}
 			m_pSocketThread->SendEvents();
 		}
 	}
