@@ -9,35 +9,40 @@
 // For example the event table entry could look like this:
 //     EVT_FZ_NOTIFICATION(wxID_ANY, CMainFrame::OnEngineEvent)
 // and the handler function has the following declaration:
-//     void OnEngineEvent(wxEvent& event);
-// You can get the engine which sent the event by calling
-//     event.GetEventObject()
+//     void OnEngineEvent(wxFzEvent& event);
+// You can get the engine which sent the event by reading
+//     event.engine_
 // Whenever you get a notification event,
 // CFileZillaEngine::GetNextNotification has to be called until it returns 0,
 // or you will lose important notifications or your memory will fill with
 // pending notifications.
 
-// A special class of notifications are the asynchronous requests. These 
-// requests have to be answered. Once proessed, call 
+// A special class of notifications are the asynchronous requests. These
+// requests have to be answered. Once proessed, call
 // CFileZillaEngine::SetAsyncRequestReply to continue the current operation.
 
 #include "local_path.h"
+#include "timeex.h"
 
-extern const wxEventType fzEVT_NOTIFICATION;
-#define EVT_FZ_NOTIFICATION(id, fn) \
-    DECLARE_EVENT_TABLE_ENTRY( \
-        fzEVT_NOTIFICATION, id, -1, \
-        (wxObjectEventFunction)(wxEventFunction) wxStaticCastEvent( wxEventFunction, &fn ), \
-        (wxObject *) NULL \
-    ),
-
-class wxFzEvent : public wxEvent
+class CFileZillaEngine;
+class wxFzEvent final : public wxEvent
 {
 public:
-	wxFzEvent(int id = wxID_ANY);
+	wxFzEvent();
+
+	explicit wxFzEvent(int id);
+	explicit wxFzEvent(CFileZillaEngine const* engine);
+
 	virtual wxEvent *Clone() const;
+
+	CFileZillaEngine const* engine_;
 };
 
+wxDECLARE_EVENT(fzEVT_NOTIFICATION, wxFzEvent);
+
+#define EVT_FZ_NOTIFICATION(id, func) \
+	wx__DECLARE_EVT1(fzEVT_NOTIFICATION, id, &func)
+
 enum NotificationId
 {
 	nId_logmsg,				// notification about new messages for the message log
@@ -59,98 +64,113 @@ enum RequestId
 	reqId_interactiveLogin, // gives a challenge prompt for a password
 	reqId_hostkey,			// used only by SSH/SFTP to indicate new host key
 	reqId_hostkeyChanged,	// used only by SSH/SFTP to indicate changed host key
-	reqId_certificate		// sent after a successful TLS/SSL handshake to allow certificate
+	reqId_certificate		// sent after a successful TLS handshake to allow certificate
 							// validation
 };
 
 class CNotification
 {
 public:
-	CNotification();
-	virtual ~CNotification();
-	virtual enum NotificationId GetID() const = 0;
+	virtual ~CNotification() {}; // TODO: One GCC >= 4.8 is in Debian Stable (Jessie by then), make default and add testcase to configure.
+	virtual NotificationId GetID() const = 0;
+
+protected:
+	CNotification() = default;
+	CNotification(CNotification const&) = default;
+	CNotification& operator=(CNotification const&) = default;
 };
 
-class CLogmsgNotification : public CNotification
+template<NotificationId id>
+class CNotificationHelper : public CNotification
 {
 public:
-	CLogmsgNotification();
-	virtual ~CLogmsgNotification();
-	virtual enum NotificationId GetID() const;
+	virtual NotificationId GetID() const final { return id; }
+
+protected:
+	CNotificationHelper<id>() = default;
+	CNotificationHelper<id>(CNotificationHelper<id> const&) = default;
+	CNotificationHelper<id>& operator=(CNotificationHelper<id> const&) = default;
+};
+
+class CLogmsgNotification final : public CNotificationHelper<nId_logmsg>
+{
+public:
+	explicit CLogmsgNotification(MessageType t)
+		: msgType(t)
+	{}
+
+	template<typename String>
+	CLogmsgNotification(MessageType t, String && m)
+		: msg(std::forward<String>(m))
+		, msgType(t)
+	{
+	}
 
 	wxString msg;
-	enum MessageType msgType; // Type of message, see logging.h for details
+	MessageType msgType{MessageType::Status}; // Type of message, see logging.h for details
 };
 
 // If CFileZillaEngine does return with FZ_REPLY_WOULDBLOCK, you will receive
 // a nId_operation notification once the operation ends.
-class COperationNotification : public CNotification
+class COperationNotification final : public CNotificationHelper<nId_operation>
 {
 public:
-	COperationNotification();
-	virtual ~COperationNotification();
-	virtual enum NotificationId GetID() const;
-	
-	int nReplyCode;
-	enum Command commandId;
+	int nReplyCode{};
+	Command commandId{Command::none};
 };
 
 // You get this type of notification everytime a directory listing has been
 // requested explicitely or when a directory listing was retrieved implicitely
 // during another operation, e.g. file transfers.
 class CDirectoryListing;
-class CDirectoryListingNotification : public CNotification
+class CDirectoryListingNotification final : public CNotificationHelper<nId_listing>
 {
 public:
-	CDirectoryListingNotification(const CServerPath& path, const bool modified = false, const bool failed = false);
-	virtual ~CDirectoryListingNotification();
-	virtual enum NotificationId GetID() const;
+	explicit CDirectoryListingNotification(const CServerPath& path, const bool modified = false, const bool failed = false);
 	bool Modified() const { return m_modified; }
 	bool Failed() const { return m_failed; }
 	const CServerPath GetPath() const { return m_path; }
 
 protected:
-	bool m_modified;
-	bool m_failed;
+	bool m_modified{};
+	bool m_failed{};
 	CServerPath m_path;
 };
 
-class CAsyncRequestNotification : public CNotification
+class CAsyncRequestNotification : public CNotificationHelper<nId_asyncrequest>
 {
 public:
-	CAsyncRequestNotification();
-	virtual ~CAsyncRequestNotification();
-	virtual enum NotificationId GetID() const;
-
 	virtual enum RequestId GetRequestID() const = 0;
+	unsigned int requestNumber{}; // Do never change this
 
-	unsigned int requestNumber; // Do never change this
+protected:
+	CAsyncRequestNotification() = default;
+	CAsyncRequestNotification(CAsyncRequestNotification const&) = default;
+	CAsyncRequestNotification& operator=(CAsyncRequestNotification const&) = default;
 };
 
-class CFileExistsNotification : public CAsyncRequestNotification
+class CFileExistsNotification final : public CAsyncRequestNotification
 {
 public:
-	CFileExistsNotification();
-	virtual ~CFileExistsNotification();
 	virtual enum RequestId GetRequestID() const;
 
-	bool download;
+	bool download{};
 
 	wxString localFile;
-	wxLongLong localSize;
-	wxDateTime localTime;
+	wxLongLong localSize{-1};
+	CDateTime localTime;
 
 	wxString remoteFile;
 	CServerPath remotePath;
-	wxLongLong remoteSize;
-	wxDateTime remoteTime;
+	wxLongLong remoteSize{-1};
+	CDateTime remoteTime;
 
-	bool ascii;
+	bool ascii{};
 
-	bool canResume;
+	bool canResume{};
 
 	// overwriteAction will be set by the request handler
-	enum OverwriteAction
+	enum OverwriteAction : signed char
 	{
 		unknown = -1,
 		ask,
@@ -166,22 +186,21 @@ public:
 	};
 
 	// Set overwriteAction to the desired action
-	enum OverwriteAction overwriteAction;
-	
+	OverwriteAction overwriteAction{unknown};
+
 	// Set to new filename if overwriteAction is rename. Might trigger further
 	// file exists notifications if new target file exists as well.
-	wxString newName; 
+	wxString newName;
 };
 
-class CInteractiveLoginNotification : public CAsyncRequestNotification
+class CInteractiveLoginNotification final : public CAsyncRequestNotification
 {
 public:
 	CInteractiveLoginNotification(const wxString& challenge);
-	virtual ~CInteractiveLoginNotification();
 	virtual enum RequestId GetRequestID() const;
 
 	// Set to true if you have set a password
-	bool passwordSet;
+	bool passwordSet{};
 
 	// Set password by calling server.SetUser
 	CServer server;
@@ -194,81 +213,90 @@ protected:
 };
 
 // Indicate network action.
-class CActiveNotification : public CNotification
+class CActiveNotification final : public CNotificationHelper<nId_active>
 {
 public:
-	CActiveNotification(int direction);
-	virtual ~CActiveNotification();
-	virtual enum NotificationId GetID() const;
+	explicit CActiveNotification(int direction);
+
 	int GetDirection() const { return m_direction; }
 protected:
 	const int m_direction;
 };
 
-class CTransferStatus
+class CTransferStatus final
 {
 public:
+	CTransferStatus() {}
+	CTransferStatus(wxFileOffset total, wxFileOffset start, bool l)
+		: totalSize(total)
+		, startOffset(start)
+		, currentOffset(start)
+		, list(l)
+	{}
+
 	wxDateTime started;
-	wxFileOffset totalSize;		// Total size of the file to transfer, -1 if unknown
-	wxFileOffset startOffset;
-	wxFileOffset currentOffset;
+	wxFileOffset totalSize{-1};		// Total size of the file to transfer, -1 if unknown
+	wxFileOffset startOffset{-1};
+	wxFileOffset currentOffset{-1};
+
+	void clear() { startOffset = -1; }
+	bool empty() const { return startOffset < 0; }
+
+	explicit operator bool() const { return !empty(); }
 
 	// True on download notifications iff currentOffset != startOffset.
 	// True on FTP upload notifications iff currentOffset != startOffset
 	// AND after the first accepted data after the first wxSOCKET_WOULDBLOCK.
 	// SFTP uploads: Set to true if currentOffset >= startOffset + 65536.
-	bool madeProgress;
+	bool madeProgress{};
 
-	bool list;
+	bool list{};
 };
 
-class CTransferStatusNotification : public CNotification
+class CTransferStatusNotification final : public CNotificationHelper<nId_transferstatus>
 {
 public:
-	CTransferStatusNotification(CTransferStatus *pStatus);
-	virtual ~CTransferStatusNotification();
-	virtual enum  NotificationId GetID() const;
+	CTransferStatusNotification() {}
+	CTransferStatusNotification(CTransferStatus const& status);
+
+	CTransferStatus const& GetStatus() const;
 
-    const CTransferStatus *GetStatus() const;
-	
 protected:
-	CTransferStatus *m_pStatus;
+	CTransferStatus const status_;
 };
 
 // Notification about new or changed hostkeys, only used by SSH/SFTP transfers.
 // GetRequestID() returns either reqId_hostkey or reqId_hostkeyChanged
-class CHostKeyNotification : public CAsyncRequestNotification
+class CHostKeyNotification final : public CAsyncRequestNotification
 {
 public:
-    CHostKeyNotification(wxString host, int port, wxString fingerprint, bool changed = false);
-    virtual ~CHostKeyNotification();
-    virtual enum RequestId GetRequestID() const;
+	CHostKeyNotification(wxString host, int port, wxString fingerprint, bool changed = false);
+	virtual enum RequestId GetRequestID() const;
 
-    wxString GetHost() const;
-    int GetPort() const;
-    wxString GetFingerprint() const;
+	wxString GetHost() const;
+	int GetPort() const;
+	wxString GetFingerprint() const;
 
 	// Set to true if you trust the server
-	bool m_trust;
+	bool m_trust{};
 
-	// If m_truest is true, set this to true to always trust this server 
+	// If m_truest is true, set this to true to always trust this server
 	// in future.
-	bool m_alwaysTrust;
+	bool m_alwaysTrust{};
 
 protected:
 
-    const wxString m_host;
-    const int m_port;
-    const wxString m_fingerprint;
-    const bool m_changed;
+	const wxString m_host;
+	const int m_port;
+	const wxString m_fingerprint;
+	const bool m_changed;
 };
 
-class CDataNotification : public CNotification
+class CDataNotification final : public CNotificationHelper<nId_data>
 {
 public:
 	CDataNotification(char* pData, int len);
 	virtual ~CDataNotification();
-	virtual enum NotificationId GetID() const { return nId_data; }
 
 	char* Detach(int& len);
 
@@ -277,20 +305,24 @@ protected:
 	unsigned int m_len;
 };
 
-class CCertificate
+class CCertificate final
 {
 public:
+	CCertificate() = default;
 	CCertificate(
-		const unsigned char* rawData, unsigned int len,
-		wxDateTime activationTime, wxDateTime expirationTime,
-		const wxString& serial,
-		const wxString& pkalgoname, unsigned int bits,
-		const wxString& fingerprint_md5,
-		const wxString& fingerprint_sha1,
-		const wxString& subject,
-		const wxString& issuer);
-	CCertificate(const CCertificate& op);
-	virtual ~CCertificate();
+		unsigned char const* rawData, unsigned int len,
+		wxDateTime const& activationTime, wxDateTime const& expirationTime,
+		wxString const& serial,
+		wxString const& pkalgoname, unsigned int bits,
+		wxString const& signalgoname,
+		wxString const& fingerprint_sha256,
+		wxString const& fingerprint_sha1,
+		wxString const& issuer,
+		wxString const& subject,
+		std::vector<wxString> const& altSubjectNames);
+
+	CCertificate(CCertificate const& op);
+	~CCertificate();
 
 	const unsigned char* GetRawData(unsigned int& len) const { len = m_len; return m_rawData; }
 	wxDateTime GetActivationTime() const { return m_activationTime; }
@@ -300,40 +332,49 @@ public:
 	const wxString& GetPkAlgoName() const { return m_pkalgoname; }
 	unsigned int GetPkAlgoBits() const { return m_pkalgobits; }
 
-	const wxString& GetFingerPrintMD5() const { return m_fingerprint_md5; }
+	const wxString& GetSignatureAlgorithm() const { return m_signalgoname; }
+
+	const wxString& GetFingerPrintSHA256() const { return m_fingerprint_sha256; }
 	const wxString& GetFingerPrintSHA1() const { return m_fingerprint_sha1; }
 
 	const wxString& GetSubject() const { return m_subject; }
 	const wxString& GetIssuer() const { return m_issuer; }
 
-	CCertificate& operator=(const CCertificate &op);
+	CCertificate& operator=(CCertificate const& op);
+
+	std::vector<wxString> const& GetAltSubjectNames() const { return m_altSubjectNames; }
 
 private:
 	wxDateTime m_activationTime;
 	wxDateTime m_expirationTime;
 
-	unsigned char* m_rawData;
-	unsigned int m_len;
+	unsigned char* m_rawData{};
+	unsigned int m_len{};
 
 	wxString m_serial;
 	wxString m_pkalgoname;
-	unsigned int m_pkalgobits;
+	unsigned int m_pkalgobits{};
 
-	wxString m_fingerprint_md5;
+	wxString m_signalgoname;
+
+	wxString m_fingerprint_sha256;
 	wxString m_fingerprint_sha1;
 
-	wxString m_subject;
 	wxString m_issuer;
+	wxString m_subject;
+
+	std::vector<wxString> m_altSubjectNames;
 };
 
-class CCertificateNotification : public CAsyncRequestNotification
+class CCertificateNotification final : public CAsyncRequestNotification
 {
 public:
 	CCertificateNotification(const wxString& host, unsigned int port,
+		const wxString& protocol,
+		const wxString& keyExchange,
 		const wxString& sessionCipher,
 		const wxString& sessionMac,
 		const std::vector<CCertificate> &certificates);
-	virtual ~CCertificateNotification();
 	virtual enum RequestId GetRequestID() const { return reqId_certificate; }
 
 	const wxString& GetHost() const { return m_host; }
@@ -342,25 +383,28 @@ public:
 	const wxString& GetSessionCipher() const { return m_sessionCipher; }
 	const wxString& GetSessionMac() const { return m_sessionMac; }
 
-	bool m_trusted;
+	bool m_trusted{};
 
 	const std::vector<CCertificate> GetCertificates() const { return m_certificates; }
 
+	const wxString& GetProtocol() const { return m_protocol; }
+	const wxString& GetKeyExchange() const { return m_keyExchange; }
+
 protected:
 	wxString m_host;
-	unsigned int m_port;
+	unsigned int m_port{};
 
+	wxString m_protocol;
+	wxString m_keyExchange;
 	wxString m_sessionCipher;
 	wxString m_sessionMac;
 
 	std::vector<CCertificate> m_certificates;
 };
 
-class CSftpEncryptionNotification : public CNotification
+class CSftpEncryptionNotification : public CNotificationHelper<nId_sftp_encryption>
 {
 public:
-	virtual enum NotificationId GetID() const { return nId_sftp_encryption; }
-
 	wxString hostKey;
 	wxString kexAlgorithm;
 	wxString kexHash;
@@ -370,11 +414,9 @@ public:
 	wxString macServerToClient;
 };
 
-class CLocalDirCreatedNotification : public CNotification
+class CLocalDirCreatedNotification : public CNotificationHelper<nId_local_dir_created>
 {
 public:
-	virtual enum NotificationId GetID() const { return nId_local_dir_created; }
-
 	CLocalPath dir;
 };
 
