@@ -64,7 +64,7 @@ void CQueueViewFailed::OnRemoveAll(wxCommandEvent& event)
 	if (pEditHandler)
 		pEditHandler->RemoveAll(CEditHandler::upload_and_remove_failed);
 
-	for (std::vector<CServerItem*>::iterator iter = m_serverList.begin(); iter != m_serverList.end(); iter++)
+	for (auto iter = m_serverList.begin(); iter != m_serverList.end(); ++iter)
 		delete *iter;
 	m_serverList.clear();
 
@@ -91,7 +91,7 @@ void CQueueViewFailed::OnRemoveSelected(wxCommandEvent& event)
 
 	std::list<CQueueItem*> selectedItems;
 	long item = -1;
-	while (true)
+	for (;;)
 	{
 		item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
 		if (item == -1)
@@ -110,13 +110,13 @@ void CQueueViewFailed::OnRemoveSelected(wxCommandEvent& event)
 
 		CQueueItem* pTopLevelItem = pItem->GetTopLevelItem();
 
-		if (pItem->GetType() == QueueItemType_Server)
+		if (pItem->GetType() == QueueItemType::Server)
 		{
 			CServerItem* pServerItem = (CServerItem*)pItem;
 			if (pEditHandler && pEditHandler->GetFileCount(CEditHandler::remote, CEditHandler::upload_and_remove_failed, &pServerItem->GetServer()))
 				pEditHandler->RemoveAll(CEditHandler::upload_and_remove_failed, &pServerItem->GetServer());
 		}
-		else if (pItem->GetType() == QueueItemType_File)
+		else if (pItem->GetType() == QueueItemType::File)
 		{
 			CFileItem* pFileItem = (CFileItem*)pItem;
 			if (pFileItem->m_edit == CEditHandler::remote && pEditHandler)
@@ -160,7 +160,7 @@ bool CQueueViewFailed::RequeueFileItem(CFileItem* pFileItem, CServerItem* pServe
 	CQueueView* pQueueView = m_pQueue->GetQueueView();
 
 	pFileItem->m_errorCount = 0;
-	pFileItem->m_statusMessage.Clear();
+	pFileItem->SetStatusMessage(CFileItem::none);
 
 	if (!pFileItem->Download() && !wxFileName::FileExists(pFileItem->GetLocalPath().GetPath() + pFileItem->GetLocalFile()))
 	{
@@ -186,7 +186,7 @@ bool CQueueViewFailed::RequeueFileItem(CFileItem* pFileItem, CServerItem* pServe
 				delete pFileItem;
 				return false;
 			}
-			pFileItem->SetLocalFile(file);
+			pFileItem->SetTargetFile(file);
 		}
 		else if (state == CEditHandler::upload_and_remove_failed)
 		{
@@ -229,19 +229,18 @@ bool CQueueViewFailed::RequeueServerItem(CServerItem* pServerItem)
 	m_fileCount -= childrenCount;
 	m_itemCount -= childrenCount + 1;
 	pServerItem->DetachChildren();
-	delete pServerItem;
 
 	std::vector<CServerItem*>::iterator iter;
-	for (iter = m_serverList.begin(); iter != m_serverList.end(); iter++)
-	{
+	for (iter = m_serverList.begin(); iter != m_serverList.end(); ++iter) {
 		if (*iter == pServerItem)
 			break;
 	}
 	if (iter != m_serverList.end())
 		m_serverList.erase(iter);
 
-	if (!pTargetServerItem->GetChildrenCount(false))
-	{
+	delete pServerItem;
+
+	if (!pTargetServerItem->GetChildrenCount(false)) {
 		pQueueView->CommitChanges();
 		pQueueView->RemoveItem(pTargetServerItem, true, true, true);
 	}
@@ -261,7 +260,7 @@ void CQueueViewFailed::OnRequeueSelected(wxCommandEvent& event)
 	std::list<CQueueItem*> selectedItems;
 	long item = -1;
 	long skipTo = -1;
-	while (true)
+	for (;;)
 	{
 		item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
 		if (item == -1)
@@ -271,7 +270,7 @@ void CQueueViewFailed::OnRequeueSelected(wxCommandEvent& event)
 			continue;
 
 		CQueueItem* pItem = GetQueueItem(item);
-		if (pItem->GetType() == QueueItemType_Server)
+		if (pItem->GetType() == QueueItemType::Server)
 			skipTo = item + pItem->GetChildrenCount(true) + 1;
 		selectedItems.push_back(GetQueueItem(item));
 	}
@@ -286,7 +285,7 @@ void CQueueViewFailed::OnRequeueSelected(wxCommandEvent& event)
 		CQueueItem* pItem = selectedItems.front();
 		selectedItems.pop_front();
 
-		if (pItem->GetType() == QueueItemType_Server)
+		if (pItem->GetType() == QueueItemType::Server)
 		{
 			CServerItem* pServerItem = (CServerItem*)pItem;
 			failedToRequeueAll |= !RequeueServerItem(pServerItem);
@@ -314,7 +313,7 @@ void CQueueViewFailed::OnRequeueSelected(wxCommandEvent& event)
 
 	if (pQueueView->IsActive())
 		pQueueView->AdvanceQueue(false);
-	
+
 	DisplayNumberQueuedFiles();
 	SaveSetItemCount(m_itemCount);
 	RefreshListOnly();
@@ -323,7 +322,7 @@ void CQueueViewFailed::OnRequeueSelected(wxCommandEvent& event)
 		m_pQueue->SetSelection(0);
 
 	if (failedToRequeueAll)
-		wxMessageBox(_("Not all items could be requeued for viewing/editing."));
+		wxMessageBoxEx(_("Not all items could be requeued for transfer."));
 }
 
 void CQueueViewFailed::OnRequeueAll(wxCommandEvent& event)
@@ -339,7 +338,7 @@ void CQueueViewFailed::OnRequeueAll(wxCommandEvent& event)
 
 	if (pQueueView->IsActive())
 		pQueueView->AdvanceQueue(false);
-	
+
 	DisplayNumberQueuedFiles();
 	SaveSetItemCount(m_itemCount);
 	RefreshListOnly();
@@ -348,7 +347,7 @@ void CQueueViewFailed::OnRequeueAll(wxCommandEvent& event)
 		m_pQueue->SetSelection(0);
 
 	if (!ret)
-		wxMessageBox(_("Not all items could be requeued for viewing/editing."));
+		wxMessageBoxEx(_("Not all items could be requeued for transfer."));
 }
 
 void CQueueViewFailed::OnChar(wxKeyEvent& event)
