@@ -3,26 +3,16 @@
 #include "commandqueue.h"
 #include "chmoddialog.h"
 #include "filter.h"
+#include "Options.h"
 #include "queue.h"
 #include "local_filesys.h"
 
-CRecursiveOperation::CNewDir::CNewDir()
-{
-	recurse = true;
-	second_try = false;
-	link = 0;
-	doVisit = true;
-}
-
 CRecursiveOperation::CRecursiveOperation(CState* pState)
 	: CStateEventHandler(pState),
-	  m_operationMode(recursive_none), m_pState(pState)
+	  m_operationMode(recursive_none)
 {
 	pState->RegisterHandler(this, STATECHANGE_REMOTE_DIR, false);
 	pState->RegisterHandler(this, STATECHANGE_REMOTE_LINKNOTDIR, false);
-
-	m_pChmodDlg = 0;
-	m_pQueue = 0;
 }
 
 CRecursiveOperation::~CRecursiveOperation()
@@ -34,7 +24,7 @@ CRecursiveOperation::~CRecursiveOperation()
 	}
 }
 
-void CRecursiveOperation::OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString& data, const void* data2)
+void CRecursiveOperation::OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString&, const void* data2)
 {
 	if (notification == STATECHANGE_REMOTE_LINKNOTDIR)
 	{
@@ -45,15 +35,15 @@ void CRecursiveOperation::OnStateChange(CState* pState, enum t_statechange_notif
 	{
 		wxASSERT(pState);
 		wxASSERT(notification == STATECHANGE_REMOTE_DIR);
-		ProcessDirectoryListing(pState->GetRemoteDir().Value());
+		ProcessDirectoryListing(pState->GetRemoteDir().get());
 	}
 }
 
-void CRecursiveOperation::StartRecursiveOperation(enum OperationMode mode, const CServerPath& startDir, const std::list<CFilter>& filters, bool allowParent /*=false*/, const CServerPath& finalDir /*=CServerPath()*/)
+void CRecursiveOperation::StartRecursiveOperation(OperationMode mode, const CServerPath& startDir, std::vector<CFilter> const& filters, bool allowParent /*=false*/, const CServerPath& finalDir /*=CServerPath()*/)
 {
 	wxCHECK_RET(m_operationMode == recursive_none, _T("StartRecursiveOperation called with m_operationMode != recursive_none"));
 	wxCHECK_RET(m_pState->IsRemoteConnected(), _T("StartRecursiveOperation while disconnected"));
-	wxCHECK_RET(!startDir.IsEmpty(), _T("Empty startDir in StartRecursiveOperation"));
+	wxCHECK_RET(!startDir.empty(), _T("Empty startDir in StartRecursiveOperation"));
 
 	if (mode == recursive_chmod && !m_pChmodDlg)
 		return;
@@ -72,7 +62,7 @@ void CRecursiveOperation::StartRecursiveOperation(enum OperationMode mode, const
 
 	m_startDir = startDir;
 
-	if (finalDir.IsEmpty())
+	if (finalDir.empty())
 		m_finalDir = startDir;
 	else
 		m_finalDir = finalDir;
@@ -131,7 +121,7 @@ bool CRecursiveOperation::NextOperation()
 
 bool CRecursiveOperation::BelowRecursionRoot(const CServerPath& path, CNewDir &dir)
 {
-	if (!dir.start_dir.IsEmpty())
+	if (!dir.start_dir.empty())
 	{
 		if (path.IsSubdirOf(dir.start_dir, false))
 			return true;
@@ -156,10 +146,12 @@ bool CRecursiveOperation::BelowRecursionRoot(const CServerPath& path, CNewDir &d
 	return false;
 }
 
+// Defined in RemoteListView.cpp
+extern wxString StripVMSRevision(const wxString& name);
+
 void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDirectoryListing)
 {
-	if (!pDirectoryListing)
-	{
+	if (!pDirectoryListing) {
 		StopRecursiveOperation();
 		return;
 	}
@@ -167,8 +159,7 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 	if (m_operationMode == recursive_none)
 		return;
 
-	if (pDirectoryListing->m_failed)
-	{
+	if (pDirectoryListing->failed()) {
 		// Ignore this.
 		// It will get handled by the failed command in ListingFailed
 		return;
@@ -176,8 +167,7 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 
 	wxASSERT(!m_dirsToVisit.empty());
 
-	if (!m_pState->IsRemoteConnected() || m_dirsToVisit.empty())
-	{
+	if (!m_pState->IsRemoteConnected() || m_dirsToVisit.empty()) {
 		StopRecursiveOperation();
 		return;
 	}
@@ -185,14 +175,12 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 	CNewDir dir = m_dirsToVisit.front();
 	m_dirsToVisit.pop_front();
 
-	if (!BelowRecursionRoot(pDirectoryListing->path, dir))
-	{
+	if (!BelowRecursionRoot(pDirectoryListing->path, dir)) {
 		NextOperation();
 		return;
 	}
 
-	if (m_operationMode == recursive_delete && dir.doVisit && dir.subdir != _T(""))
-	{
+	if (m_operationMode == recursive_delete && dir.doVisit && !dir.subdir.empty()) {
 		// After recursing into directory to delete its contents, delete directory itself
 		// Gets handled in NextOperation
 		CNewDir dir2 = dir;
@@ -200,8 +188,7 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 		m_dirsToVisit.push_front(dir2);
 	}
 
-	if (dir.link && !dir.recurse)
-	{
+	if (dir.link && !dir.recurse) {
 		NextOperation();
 		return;
 	}
@@ -216,16 +203,13 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 	const CServer* pServer = m_pState->GetServer();
 	wxASSERT(pServer);
 
-	if (!pDirectoryListing->GetCount())
-	{
-		if (m_operationMode == recursive_download)
-		{
+	if (!pDirectoryListing->GetCount()) {
+		if (m_operationMode == recursive_download) {
 			wxFileName::Mkdir(dir.localDir.GetPath(), 0777, wxPATH_MKDIR_FULL);
 			m_pState->RefreshLocalFile(dir.localDir.GetPath());
 		}
-		else if (m_operationMode == recursive_addtoqueue)
-		{
-			m_pQueue->QueueFile(true, true, dir.localDir, _T(""), _T(""), CServerPath(), *pServer, -1);
+		else if (m_operationMode == recursive_addtoqueue) {
+			m_pQueue->QueueFile(true, true, _T(""), _T(""), dir.localDir, CServerPath(), *pServer, -1);
 			m_pQueue->QueueFile_Finish(false);
 		}
 	}
@@ -233,65 +217,65 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 	CFilterManager filter;
 
 	// Is operation restricted to a single child?
-	bool restrict = !dir.restrict.IsEmpty();
+	bool restrict = !dir.restrict.empty();
 
-	std::list<wxString> filesToDelete;
+	std::deque<wxString> filesToDelete;
 
 	const wxString path = pDirectoryListing->path.GetPath();
-	
+
 	bool added = false;
 
-	for (int i = pDirectoryListing->GetCount() - 1; i >= 0; --i)
-	{
+	for (int i = pDirectoryListing->GetCount() - 1; i >= 0; --i) {
 		const CDirentry& entry = (*pDirectoryListing)[i];
 
-		if (restrict)
-		{
+		if (restrict) {
 			if (entry.name != dir.restrict)
 				continue;
 		}
-		else if (filter.FilenameFiltered(m_filters, entry.name, path, entry.is_dir(), entry.size, false, 0, entry.has_date() ? &entry.time : 0))
+		else if (filter.FilenameFiltered(m_filters, entry.name, path, entry.is_dir(), entry.size, false, 0, entry.time))
 			continue;
 
-		if (entry.is_dir() && (!entry.is_link() || m_operationMode != recursive_delete))
-		{
-			if (dir.recurse)
-			{
+		if (entry.is_dir() && (!entry.is_link() || m_operationMode != recursive_delete)) {
+			if (dir.recurse) {
 				CNewDir dirToVisit;
 				dirToVisit.parent = pDirectoryListing->path;
 				dirToVisit.subdir = entry.name;
 				dirToVisit.localDir = dir.localDir;
 				dirToVisit.start_dir = dir.start_dir;
-				
+
 				if (m_operationMode == recursive_download || m_operationMode == recursive_addtoqueue)
 					dirToVisit.localDir.AddSegment(CQueueView::ReplaceInvalidCharacters(entry.name));
-				if (entry.is_link())
-				{
+				if (entry.is_link()) {
 					dirToVisit.link = 1;
 					dirToVisit.recurse = false;
 				}
 				m_dirsToVisit.push_front(dirToVisit);
 			}
 		}
-		else
-		{
+		else {
 			switch (m_operationMode)
 			{
 			case recursive_download:
 			case recursive_download_flatten:
 				{
+					wxString localFile = CQueueView::ReplaceInvalidCharacters(entry.name);
+					if (pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+						localFile = StripVMSRevision(localFile);
 					m_pQueue->QueueFile(m_operationMode == recursive_addtoqueue, true,
-						dir.localDir, CQueueView::ReplaceInvalidCharacters(entry.name),
-						entry.name, pDirectoryListing->path, *pServer, entry.size);
+						entry.name, (entry.name == localFile) ? wxString() : localFile,
+						dir.localDir, pDirectoryListing->path, *pServer, entry.size.GetValue());
 					added = true;
 				}
 				break;
 			case recursive_addtoqueue:
 			case recursive_addtoqueue_flatten:
 				{
+					wxString localFile = CQueueView::ReplaceInvalidCharacters(entry.name);
+					if (pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+						localFile = StripVMSRevision(localFile);
 					m_pQueue->QueueFile(true, true,
-						dir.localDir, CQueueView::ReplaceInvalidCharacters(entry.name),
-						entry.name, pDirectoryListing->path, *pServer, entry.size);
+						entry.name, (entry.name == localFile) ? wxString() : localFile,
+						dir.localDir, pDirectoryListing->path, *pServer, entry.size.GetValue());
 					added = true;
 				}
 				break;
@@ -303,15 +287,14 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 			}
 		}
 
-		if (m_operationMode == recursive_chmod && m_pChmodDlg)
-		{
+		if (m_operationMode == recursive_chmod && m_pChmodDlg) {
 			const int applyType = m_pChmodDlg->GetApplyType();
 			if (!applyType ||
 				(!entry.is_dir() && applyType == 1) ||
 				(entry.is_dir() && applyType == 2))
 			{
 				char permissions[9];
-				bool res = m_pChmodDlg->ConvertPermissions(entry.permissions, permissions);
+				bool res = m_pChmodDlg->ConvertPermissions(*entry.permissions, permissions);
 				wxString newPerms = m_pChmodDlg->GetPermissions(res ? permissions : 0, entry.is_dir());
 				m_pState->m_pCommandQueue->ProcessCommand(new CChmodCommand(pDirectoryListing->path, entry.name, newPerms));
 			}
@@ -321,7 +304,7 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 		m_pQueue->QueueFile_Finish(m_operationMode != recursive_addtoqueue && m_operationMode != recursive_addtoqueue_flatten);
 
 	if (m_operationMode == recursive_delete && !filesToDelete.empty())
-		m_pState->m_pCommandQueue->ProcessCommand(new CDeleteCommand(pDirectoryListing->path, filesToDelete));
+		m_pState->m_pCommandQueue->ProcessCommand(new CDeleteCommand(pDirectoryListing->path, std::move(filesToDelete)));
 
 	NextOperation();
 }
@@ -358,6 +341,12 @@ void CRecursiveOperation::ListingFailed(int error)
 	if (m_operationMode == recursive_none)
 		return;
 
+	if( (error & FZ_REPLY_CANCELED) == FZ_REPLY_CANCELED) {
+		// User has cancelled operation
+		StopRecursiveOperation();
+		return;
+	}
+
 	wxASSERT(!m_dirsToVisit.empty());
 	if (m_dirsToVisit.empty())
 		return;
@@ -403,30 +392,26 @@ void CRecursiveOperation::LinkIsNotDir()
 	m_dirsToVisit.pop_front();
 
 	const CServer* pServer = m_pState->GetServer();
-	if (!pServer)
-	{
+	if (!pServer) {
 		NextOperation();
 		return;
 	}
 
-	if (m_operationMode == recursive_delete)
-	{
-		if (!dir.subdir.empty())
-		{
-			std::list<wxString> files;
+	if (m_operationMode == recursive_delete) {
+		if (!dir.subdir.empty()) {
+			std::deque<wxString> files;
 			files.push_back(dir.subdir);
-			m_pState->m_pCommandQueue->ProcessCommand(new CDeleteCommand(dir.parent, files));
+			m_pState->m_pCommandQueue->ProcessCommand(new CDeleteCommand(dir.parent, std::move(files)));
 		}
 		NextOperation();
 		return;
 	}
-	else if (m_operationMode != recursive_list )
-	{
+	else if (m_operationMode != recursive_list) {
 		CLocalPath localPath = dir.localDir;
 		wxString localFile = dir.subdir;
 		if (m_operationMode != recursive_addtoqueue_flatten && m_operationMode != recursive_download_flatten)
 			localPath.MakeParent();
-		m_pQueue->QueueFile(m_operationMode == recursive_addtoqueue || m_operationMode == recursive_addtoqueue_flatten, true, localPath, localFile, dir.subdir, dir.parent, *pServer, -1);
+		m_pQueue->QueueFile(m_operationMode == recursive_addtoqueue || m_operationMode == recursive_addtoqueue_flatten, true, dir.subdir, (dir.subdir == localFile) ? wxString() : localFile, localPath, dir.parent, *pServer, -1);
 		m_pQueue->QueueFile_Finish(m_operationMode != recursive_addtoqueue);
 	}
 
